package cz.frantovo.nekurak.web;

import java.util.Collections;
import java.util.HashMap;
import java.util.Map;
import java.util.logging.Level;
import java.util.logging.Logger;

/**
 *
 * @author fiki
 */
public class RegistraceUzivatele {

    private HledacSluzby hledac = new HledacSluzby();
    private static final Logger log = Logger.getLogger(RegistraceUzivatele.class.getSimpleName());
    private Map<String, UzivatelPredRegistraci> uzivatele = Collections.synchronizedMap(new HashMap<String, UzivatelPredRegistraci>());
    private String token;

    /**
     * Přidáme uživatelský účet do mapy místo abychom použili prostou proměnnou.
     * Uživatel si totiž může otevřít víc registračních formulářů,
     * postupně je vyplnit a pak potvrdit jeden z nich.
     * Takto nedojde k přepsání údajů z předchozích vyplněných formulářů.
     */
    public void setUzivatel(UzivatelPredRegistraci uzivatel) {
	uzivatele.put(uzivatel.getToken(), uzivatel);
    }

    public void setToken(String token) {
	this.token = token;
    }

    /**
     * @return null, pokud je vše v pořádku.
     * Jinak vrací chybovou hlášku (resp. klíč k lokalizaci)
     */
    public String getDokonciRegistraci() {

	UzivatelPredRegistraci u = uzivatele.get(token);

	if (u == null) {
	    /** Chybný token – uživatel se snaží dokončit neexistující registraci */
	    return "registrace.vyjimka.token";
	} else {
	    try {
		hledac.getUzivatelEJB().registrujUzivatele(u.getUzivatel());
	    } catch (Exception e) {
		log.log(Level.WARNING, "Chyba při registraci uživatele.", e);
		return "registrace.vyjimka";
	    }
	    return null;
	}
    }
}
